@@ -33,6 +33,7 @@ class CSVWriter(FileWriter):
             'address': 'Адрес', 'address_comment': 'Комментарий к адресу',
             'postcode': 'Почтовый индекс', 'living_area': 'Микрорайон', 'district': 'Район', 'city': 'Город',
             'district_area': 'Округ', 'region': 'Регион', 'country': 'Страна', 'schedule': 'Часы работы',
+            'timezone': 'Часовой пояс',
         }
 
         # Expand complex mapping
@@ -69,8 +70,8 @@ class CSVWriter(FileWriter):
         self._wrote_count = 0
         return self
 
-    def __exit__(self, *args, **kwargs) -> None:
-        super().__exit__(*args, **kwargs)
+    def __exit__(self, *exc_info) -> None:
+        super().__exit__(*exc_info)
         if self._options.csv.remove_empty_columns:
             logger.info('Удаление пустых колонок CSV.')
             self._remove_empty_columns()
@@ -201,6 +202,10 @@ class CSVWriter(FileWriter):
         if catalog_item.address:
             data['postcode'] = catalog_item.address.postcode
 
+        # Timezone
+        if catalog_item.timezone is not None:
+            data['timezone'] = catalog_item.timezone
+
         # Administrative location details
         for div in catalog_item.adm_div:
             for t in ('country', 'region', 'district_area', 'city', 'district', 'living_area'):
